Azure Backend
=============

You can have Coiled launch computations on Azure. Your computations will run
inside Coiled's Azure account, this makes it easy for you to get started quickly,
without needing to set up any additional infrastructure.

.. note::

    The Azure support is currently only available to early adopters.
    If you would like to test out Coiled on Azure please contact support@coiled.io.

.. tip::

    In addition to the usual cluster logs, our current Azure support also includes
    system-level logs. This provides rich insight into any potential issues while
    Azure support is still experimental.


Switching Coiled to run on Azure
--------------------------------

To use Coiled on Azure select "Azure" in the "Cloud Backend Options" section of the
Account page of your Coiled account.


Region
------

Azure support is currently only available in the ``East US`` region. If you have data in a
different region on Azure, you may be charged transfer fees.